@@ -10,8 +10,8 @@ test_that("ctcisQTL works", {
   Y    = GSE79262small$Y
   Ypos = GSE79262small$Ypos
   C    = GSE79262small$C
-  Y    = Y[seq(1, 601, 20), ] # for brevity
-  Ypos = Ypos[seq(1, 601, 20)]
+  X    = X[seq(1, 3601, 100), ] # for brevity
+  Xpos = Xpos[seq(1, 3601, 100)]
   ctcisQTL(X, Xpos, W, Y, Ypos, C = C)
   new = read.table(file.path(tempdir(), "ctcisQTL.out.txt"),
                    header = TRUE)
